@@ -35,6 +35,7 @@ define([
             /** Write codes executed before rendering */
             this.config.dataview = false;
             this.config.sizeLevel = 1;
+            this.config.checkModules = ['pd'];
 
             this.fileExtensions = {
                 'csv': 'csv',
@@ -310,19 +311,19 @@ define([
                     );
                 } else if (selectedType == 'pickle') {
                     $(prefix + '#path').parent().html(
-                        com_util.formatString('<input type="text" class="vp-input vp-state" id="path" index="0" placeholder="" value="" title=""><div id="vp_openFileNavigationBtn" class="{0}"></div>'
+                        com_util.formatString('<input type="text" class="vp-input vp-state" id="path" index="0" placeholder="" value="" title="" required="true"><div id="vp_openFileNavigationBtn" class="{0}"></div>'
                         , 'vp-file-browser-button')
                     );
                 } else {
                     $(this.fileState[pageType]['fileResultState']['pathInputId']).parent().html(
-                        com_util.formatString('<input type="text" class="vp-input vp-state" id="{0}" index="0" placeholder="" value="" title=""><div id="vp_openFileNavigationBtn" class="{1}"></div>'
+                        com_util.formatString('<input type="text" class="vp-input vp-state" id="{0}" index="0" placeholder="" value="" title="" required="true"><div id="vp_openFileNavigationBtn" class="{1}"></div>'
                             , 'i1'
                             , 'vp-file-browser-button')
                     );
                 }
             } else {
                 $(this.fileState[pageType]['fileResultState']['pathInputId']).parent().html(
-                    com_util.formatString('<input type="text" class="vp-input vp-state" id="{0}" index="0" placeholder="" value="" title=""><div id="vp_openFileNavigationBtn" class="{1}"></div>'
+                    com_util.formatString('<input type="text" class="vp-input vp-state" id="{0}" index="0" placeholder="" value="" title="" required="true"><div id="vp_openFileNavigationBtn" class="{1}"></div>'
                         , 'i0'
                         , 'vp-file-browser-button')
                 );
